##########
Item class
##########

.. currentmodule:: ddbmock.database.item

.. autoclass:: Item

Constructors
============

__init__
--------

.. automethod:: Item.__init__

Item manipulations
==================

filter
------

.. automethod:: Item.filter

apply_actions
-------------

.. automethod:: Item.apply_actions

assert_match_expected
---------------------

.. automethod:: Item.assert_match_expected

match
-----

.. automethod:: Item.match

field_match
-----------

.. automethod:: Item.field_match

read_key
--------

.. automethod:: Item.read_key

get_field_size
--------------

.. automethod:: Item.get_field_size

get_size
--------

.. automethod:: Item.get_size

__sub__
-------

.. automethod:: Item.__sub__



